cmake_minimum_required(VERSION 3.13)

include(${CTEST_SCRIPT_DIRECTORY}/lcgcmake-common.cmake)

set(CTEST_CMAKE_GENERATOR "Unix Makefiles")
set(CTEST_BUILD_COMMAND "make -k -j${ncpu} $ENV{TARGET}")
set(CTEST_BUILD_NAME $ENV{LCG_VERSION}-$ENV{PLATFORM})

set(CTEST_BUILD_PREFIX "$ENV{WORKSPACE}")
set(CTEST_SOURCE_DIRECTORY "${CTEST_BUILD_PREFIX}/lcgtest")
set(CTEST_BINARY_DIRECTORY "${CTEST_BUILD_PREFIX}/test_build")
set(CTEST_INSTALL_DIRECTORY "${CTEST_BUILD_PREFIX}/install")

set(options -DCMAKE_INSTALL_PREFIX=${CTEST_INSTALL_DIRECTORY}
            -DCMAKE_VERBOSE_MAKEFILE=OFF
            -DPLATFORM=${PLATFORM}
            -DBUILD_PATH=${BUILD_PATH}
            $ENV{LCG_EXTRA_OPTIONS})

ctest_start($ENV{CTEST_MODEL} TRACK $ENV{CDASH_TRACK} APPEND)
ctest_configure(BUILD   ${CTEST_BINARY_DIRECTORY}
                SOURCE  ${CTEST_SOURCE_DIRECTORY}
                OPTIONS "${options}")
ctest_submit(PARTS Configure)             
ctest_test(APPEND PARALLEL_LEVEL ${ncpu} INCLUDE_LABEL "${CTEST_LABELS}"
           RETURN_VALUE rc)
ctest_submit(PARTS Test)

if(NOT rc EQUAL 0)
   message(FATAL_ERROR "One or more tests have failed (rc = ${rc})")
endif()
